How to - Attributes and Methods
======================================

The main classes in alfred3 have a lot of useful attributes and methods.
So many in fact, that it can be hard to navigate them and to find what you
need in the alphabetical order of the API documentation. For this reason,
we provide another view of the attributes and methods of important classes,
ordered by category.


.. toctree::
    attr_exp
    attr_section
    attr_page
    attr_element
